@@ -1,5 +1,5 @@
 ## File Name: frm_fb_mh_refresh_imputed_values.R
-## File Version: 0.13
+## File Version: 0.16
 
 frm_fb_mh_refresh_imputed_values <- function( imputations_mcmc, acc_bounds, ind0 )
 {
@@ -14,8 +14,7 @@ frm_fb_mh_refresh_imputed_values <- function( imputations_mcmc, acc_bounds, ind0
             var_vv <- impute_vars[vv]
             ind0_vv <- ind0[[ var_vv ]]
             mh_imp_vv <- mh_imputations_values[[ var_vv ]]
-            mh_adapt <- ( ! is.null( mh_imp_vv) ) &
-                            ( ind0_vv$model %in% c("linreg") )
+            mh_adapt <- ( ! is.null( mh_imp_vv) ) & ( ind0_vv$model %in% c("linreg") )
             if ( mh_adapt ){
                 acc_pars <- list( mh_imp_vv[,1], mh_imp_vv[,2] )
                 res0 <- frm_proposal_refresh_helper( acceptance_parameters=acc_pars,
