@@ -1,5 +1,5 @@
 //// File Name: mdmb_rcpp_linreg.h
-//// File Version: 0.491
+//// File Version: 0.493
 
 #ifndef _MDMB_MDMB_RCPP_LINREG_H
 #define _MDMB_MDMB_RCPP_LINREG_H
@@ -23,4 +23,10 @@ Rcpp::NumericVector mdmb_rcpp_dnorm( Rcpp::NumericVector x, Rcpp::NumericVector
 Rcpp::NumericVector mdmb_rcpp_log_dnorm( Rcpp::NumericVector x, Rcpp::NumericVector mu,
     double sigma );
 
+Rcpp::NumericVector mdmb_rcpp_dnorm_double( Rcpp::NumericVector x, double mu,
+    double sigma );
+
+Rcpp::NumericVector mdmb_rcpp_log_dnorm_double( Rcpp::NumericVector x, double mu,
+    double sigma );
+
 #endif // _MDMB_MDMB_RCPP_LINREG_H
